==> gozerbot_0.6.4.2.orig.tar.gz: gozerbot-0.6.4.2/gozerplugs/plugs/update.py <==
# plugs/update.py
#
#

""" run mercurial pull -u """

__copyright__ = 'this file is in the public domain'

from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.generic import gozerpopen
from gozerbot.plughelp import plughelp
from gozerbot.lockmanager import lockmanager
import os, os.path

plughelp.add('update', 'do a mercurial update')

def handle_hgupdate(bot, ievent):
    """ update .. update the bot with mercurial hg pull -u """
    args = [""] * 3
    args[0] = "hg"
    args[1] = "pull"
    args[2] = "-u"
    try:
        proces = gozerpopen(args)
    except Exception, ex:
        ievent.reply('error running popen: %s' % str(ex))
        return
    data = proces.fromchild.readlines()
    returncode = proces.close()
    if returncode != 0:
        ievent.reply("no changes")
        return
    # show response
    res = []
    for line in data:
        res.append(line.strip())
    if res:
        ievent.reply(" .. ".join(res))

def handle_svnupdate(bot, ievent):
    args = ['svn', 'update']
    ievent.reply('running svn update')
    try:
        proces = gozerpopen(args)
    except Exception, ex:
        ievent.reply('error running popen: %s' % str(ex))
        return
    data = proces.fromchild.readlines()
    returncode = proces.close()
    if returncode != 0:
        ievent.reply('error running svn update')
        return
    res = []
    for line in data:
        res.append(line.strip())
    if res:
        ievent.reply(" .. ".join(res))

def handle_update(bot, ievent):
    lockmanager.acquire('up')
    if os.path.isdir('.hg'):
        handle_hgupdate(bot, ievent)
        lockmanager.release('up')
        return
    if os.path.isdir('.svn'):
        handle_svnupdate(bot, ievent)
        lockmanager.release('up')
        return
    ievent.reply('i need a svn or mercurial repository for update to work')
    lockmanager.release('up')

cmnds.add('update', handle_update, 'OPER')
examples.add('update', 'update the bot with mercurial or subversion', 'update')

==> gozerbot_0.8.1.orig.tar.gz: gozerbot-0.8.1/gozerplugs/plugs/update.py <==
# plugs/update.py
#
#

""" run mercurial pull -u or svn update """

__copyright__ = 'this file is in the public domain'

from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.generic import gozerpopen, handle_exception
from gozerbot.plughelp import plughelp
from gozerbot.lockmanager import lockmanager
import os, os.path

plughelp.add('update', 'do a mercurial or subversion update')

def handle_hgupdate(bot, ievent):
    """ update .. update the bot with mercurial hg pull -u """
    args = [""] * 3
    args[0] = "hg"
    args[1] = "pull"
    args[2] = "-u"
    try:
        proces = gozerpopen(args)
    except Exception, ex:
        ievent.reply('error running popen: %s' % str(ex))
        return
    data = proces.fromchild.readlines()
    returncode = proces.close()
    if returncode != 0:
        ievent.reply("no changes")
        return
    # show response
    res = []
    for line in data:
        res.append(line.strip())
    if res:
        ievent.reply(" .. ".join(res))

def handle_svnupdate(bot, ievent):
    """ update the bot with a svn update """
    args = ['svn', 'update']
    ievent.reply('running svn update')
    try:
        proces = gozerpopen(args)
    except Exception, ex:
        ievent.reply('error running popen: %s' % str(ex))
        return
    data = proces.fromchild.readlines()
    returncode = proces.close()
    if returncode != 0:
        ievent.reply('error running svn update')
        return
    res = []
    for line in data:
        res.append(line.strip())
    if res:
        ievent.reply(" .. ".join(res))

def handle_update(bot, ievent):
    """ run mercurial or svn update """
    lockmanager.acquire('up')
    if os.path.isdir('.hg'):
        try:
            handle_hgupdate(bot, ievent)
        except Exception, ex:
            handle_exception()
        lockmanager.release('up')
        return
    if os.path.isdir('.svn'):
        try:
            handle_svnupdate(bot, ievent)
        except Exception, ex:
            handle_exception()
        lockmanager.release('up')
        return
    ievent.reply('i need a svn or mercurial repository for update to work')
    lockmanager.release('up')

cmnds.add('update', handle_update, 'OPER')
examples.add('update', 'update the bot with mercurial or subversion .. \
the update command does NOT reboot the bot', 'update')
